package com.es.pieces;

import com.es.Board;

public interface Piece {

    public enum Color {
        BLACK("BLACK"),
        WHITE("WHITE");
        
        private final String name;
        
        private Color(String name) {
            this.name = name;
        }
        
        public String toString() {
            return name;
        }
    }

    /**
     * Returns the color of the piece.
     * @return The color of the piece.
     */
    public Color getColor();

    /**
     * Returns a sorted array of possible moves for the piece.
     *
     * There are NO checks for things like putting the king into check etc.
     *
     * @return a sorted array of possible squares the piece could move into.
     */
    public int[] generateAllMoves(Board board, int curPos);

    public int getValue();

    public int getPositionValue(int square);

    public boolean hasMoved();
    public void pieceMoved();
}
